@@ -1,9 +1,11 @@
 package Kephra::Edit::Select;
-$VERSION = '0.03';
+use strict;
+use warnings;
+
+our $VERSION = '0.03';
 
 # text selection
 
-use strict;
 use Wx qw( wxSTC_CMD_PARAUPEXTEND wxSTC_CMD_PARADOWNEXTEND );
 
 sub _ep_ref { Kephra::App::EditPanel::_ref() }
@@ -20,4 +22,4 @@ sub all_if_non {
 sub to_block_begin{ _ep_ref()->CmdKeyExecute(wxSTC_CMD_PARAUPEXTEND)   }
 sub to_block_end  { _ep_ref()->CmdKeyExecute(wxSTC_CMD_PARADOWNEXTEND) }
 
-1;
\ No newline at end of file
+1;
